aboutsummaryrefslogtreecommitdiffstats
path: root/systems/rhel/7.3/build_base_machine.sh
diff options
context:
space:
mode:
Diffstat (limited to 'systems/rhel/7.3/build_base_machine.sh')
-rwxr-xr-xsystems/rhel/7.3/build_base_machine.sh18
1 files changed, 11 insertions, 7 deletions
diff --git a/systems/rhel/7.3/build_base_machine.sh b/systems/rhel/7.3/build_base_machine.sh
index 58953e23..42c36e4c 100755
--- a/systems/rhel/7.3/build_base_machine.sh
+++ b/systems/rhel/7.3/build_base_machine.sh
@@ -52,7 +52,8 @@ pkglist=(
wget\
numactl\
numactl-devel\
- libpng-devel
+ libpng-devel\
+ sshpass\
)
# python tools for proper QEMU, DPDK, and OVS make
@@ -61,6 +62,9 @@ pkglist=(
python-six\
)
+# install RHEL compatible epel for sshpass
+yum -y install https://dl.fedoraproject.org/pub/epel/epel-release-latest-7.noarch.rpm
+
# Iterate installing each package. If packages fail to install, record those
# packages and exit with an error message on completion. Customer may need to
# add repo locations and subscription levels.
@@ -89,17 +93,17 @@ enabled=1
gpgkey=file:///etc/pki/rpm-gpg/RPM-GPG-KEY-CentOS-SIG-SCLo
EOT
# install python34 packages and git-review tool
yum -y install $(echo "
-rh-python34
-rh-python34-python-tkinter
+rh-python36
+rh-python36-python-tkinter
" | grep -v ^#)
-# cleanup python 34 repo file
-rm -f /etc/yum.repos.d/python34.repo
+# cleanup python 36 repo file
+rm -f /etc/yum.repos.d/python36.repo
# Create hugepage dirs
mkdir -p /dev/hugepages
# prevent ovs vanilla from building from source due to kernel incompatibilities
-sed -i s/'SUBBUILDS = src_vanilla'/'#SUBBUILDS = src_vanilla'/ ../src/Makefile \ No newline at end of file
+sed -i s/'SUBBUILDS = src_vanilla'/'#SUBBUILDS = src_vanilla'/ ../src/Makefile
@@ -89,17 +93,17 @@ enabled=1
gpgkey=file:///etc/pki/rpm-gpg/RPM-GPG-KEY-CentOS-SIG-SCLo
EOT
-# install python34 packages and git-review tool
+# install python36 packages and git-review tool
yum -y install $(echo "